@@ -26,11 +26,13 @@ from predectorutils.analyses import (
     DeepSig,
     EffectorP1,
     EffectorP2,
+    EffectorP3,
     Phobius,
     SignalP3HMM,
     SignalP3NN,
     SignalP4,
     SignalP5,
+    SignalP6,
     TargetPNonPlant,
     TMHMM,
     LOCALIZER,
@@ -60,6 +62,9 @@ COLUMNS = [
     "dbcan_matches",
     "effectorp1",
     "effectorp2",
+    "effectorp3_cytoplasmic",
+    "effectorp3_apoplastic",
+    "effectorp3_noneffector",
     "is_secreted",
     "any_signal_peptide",
     "apoplastp",
@@ -86,6 +91,7 @@ COLUMNS = [
     "signalp3_hmm",
     "signalp4",
     "signalp5",
+    "signalp6",
     "deepsig",
     "phobius_sp",
     "phobius_tmcount",
@@ -111,6 +117,7 @@ COLUMNS = [
     "signalp3_hmm_s",
     "signalp4_d",
     "signalp5_prob",
+    "signalp6_prob",
 ]
 
 
@@ -645,6 +652,11 @@ def construct_row(  # noqa
                 ["Effector", "Unlikely effector"]
             )
 
+        elif isinstance(an, EffectorP3):
+            record["effectorp3_cytoplasmic"] = an.cytoplasmic_prob
+            record["effectorp3_apoplastic"] = an.apoplastic_prob
+            record["effectorp3_noneffector"] = an.noneffector_prob
+
         elif isinstance(an, Phobius):
             record["phobius_sp"] = int(an.sp)
             record["phobius_tmcount"] = an.tm
@@ -676,6 +688,11 @@ def construct_row(  # noqa
             record["signalp5_prob"] = min([an.prob_signal, 1.0])
             sp_gff.extend(an.as_gff())
 
+        elif isinstance(an, SignalP6):
+            record["signalp6"] = int(an.prediction == "SP")
+            record["signalp6_prob"] = min([an.prob_signal, 1.0])
+            sp_gff.extend(an.as_gff())
+
         elif isinstance(an, TargetPNonPlant):
             record["targetp_secreted"] = int(an.prediction == "SP")
             record["targetp_secreted_prob"] = an.sp
